# -*- coding: utf-8 -*-
COMMANDS = (
    (
        'help',
        'help',
        'Display help and such.',
    ),
    (
        'quit',
        'quit',
        'Quit this program.',
    ),
    (
        'exit',
        'quit',
        'Synonym for `quit`.',
    ),
    (
        'load',
        'load',
        'Load a module',
    ),
    (
        'unload',
        'unload',
        'Unload current module',
    ),
    (
        'list',
        'list',
        'List available modules',
    ),
)
